ebs_sum — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# ebs_sum

ElectronicBandStructure.ebs_sum(atoms: List[int] | None = None, principal_q_numbers: List[int] = [-1], orbitals: List[int] | None = None, spins: List[int] | None = None, sum_noncolinear: bool = True)

  _summary_

  Parameters:

    - atoms (List[int], optional) – List of atoms to be summed over, by default None

    - principal_q_numbers (List[int], optional) – List of principal quantum numbers to be summed over, by default [-1]

    - orbitals (List[int], optional) – List of orbitals to be summed over, by default None

    - spins (List[int], optional) – List of spins to be summed over, by default None

    - sum_noncolinear (bool, optional) – Determines if the projection should be summed in a non-colinear calculation, by default True

  Returns:

    ret (list float) – The summed projections